from upload_machine.utils.uploader.piggo_upload import piggo_upload
from upload_machine.utils.uploader.hdsky_upload import hdsky_upload
from upload_machine.utils.uploader.audience_upload import audience_upload
from upload_machine.utils.uploader.ssd_upload import ssd_upload
from upload_machine.utils.uploader.pter_upload import pter_upload
from upload_machine.utils.uploader.hhclub_upload import hhclub_upload
from upload_machine.utils.uploader.lemonhd_upload import lemonhd_upload
from upload_machine.utils.uploader.hdpt_upload import hdpt_upload
from upload_machine.utils.uploader.wintersakura_upload import wintersakura_upload
from upload_machine.utils.uploader.carpt_upload import carpt_upload
from upload_machine.utils.uploader.hdfans_upload import hdfans_upload
from upload_machine.utils.uploader.hares_upload import hares_upload
from upload_machine.utils.uploader.zmpt_upload import zmpt_upload
from upload_machine.utils.uploader.hdvideo_upload import hdvideo_upload
from upload_machine.utils.uploader.ihdbits_upload import ihdbits_upload
#from upload_machine.utils.uploader.mteam_upload import mteam_upload





def auto_upload(siteitem,file,record_path,qbinfo,basic,hashlist):
    return eval(siteitem.sitename+'_upload(siteitem,file,record_path,qbinfo,basic,hashlist)')


import os
from loguru import logger
import time
import requests
import re
import json
import sys
from upload_machine.utils.mediafile.douban_book import *
from upload_machine.utils.mediafile.douban_movie import *

def getdoubaninfo(url:str='',cookie:str=''):
    if 'movie.douban.com' in url:
        if cookie.strip()=='':
            page_parse=MoviePageParse(movie_url=url)
        else:
            page_parse=MoviePageParse(movie_url=url,cookie=cookie)
    elif 'book.douban.com' in url:
        if cookie.strip()=='':
            page_parse=BookPageParse(book_url=url)
        else:
            page_parse=BookPageParse(book_url=url,cookie=cookie)
    else:
        raise Exception('豆瓣链接填写错误')
    print('\n'+page_parse.info())


def ptgen_douban_info(doubanurl):
    url='https://api.iyuu.cn/App.Movie.Ptgen?url='+doubanurl
    user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.102 Safari/537.36'
    headers = {
            'user-agent': user_agent,
            'referer': url,
        }
    logger.info('正在获取豆瓣信息')
    try:
        r = requests.get(url,headers=headers,timeout=20)
    except Exception as r:
        logger.error('获取豆瓣信息失败，原因: %s' %(r))
        return 

    logger.info('获取豆瓣信息完毕，正在处理信息，请稍等...')
    
    try:
        info_json=r.json()
        logger.trace(info_json)
    except Exception as r:
        logger.warning('获取豆瓣信息转换json格式失败，原因: %s' %(r))
        return
    
    if not r.ok:
        logger.trace(r.content)
        logger.warning(
            f"获取豆瓣信息失败: HTTP {r.status_code}, reason: {r.reason} ")
        return 

    if 'data' not in info_json or 'format' not in info_json['data']:
        logger.warning(f"豆瓣信息获取失败")
        return 
    
    info=info_json['data']['format']
    info=info[0:info.find('<a')]
    
    imgurl=re.findall('img[0-9]\.doubanio\.com',info)
    if len(imgurl)>0:
        info=info.replace(imgurl[0],'img9.doubanio.com')
    return info
    
def lemon_douban_info(doubanurl):
    url='https://movieinfo.leaguehd.com/doubanAjax.php?url='+doubanurl
    user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.102 Safari/537.36'
    headers = {
            'user-agent': user_agent,
            'referer': url,
        }
    logger.info('正在获取豆瓣信息，请稍等...')
    try:
        r = requests.get(url,headers=headers,timeout=20)
    except Exception as r:
        logger.warning('通过柠檬获取豆瓣信息失败，原因: %s' %(r))
        return

    logger.info('获取豆瓣信息完毕，正在处理信息，请稍等...')
    try:
        data=r.json()
    except Exception as r:
        logger.warning('通过柠檬获取豆瓣信息转换json格式失败，原因: %s' %(r))
        return

    douban_info=''
    
    if (data['pic']):
        imgurl=re.findall('img[0-9]\.doubanio\.com',data['pic'])
        douban_info = douban_info+"[img]" + data['pic'].replace(imgurl[0],'img9.doubanio.com') + "[/img]\n"
    if (data['allName']):
        douban_info = douban_info+ "\n◎译\u3000\u3000名　" + '/'.join(data['allName']);
    if (data['name']) :
        douban_info += "\n◎片\u3000\u3000名　" + data['name']
    if (data['year']):
        douban_info += "\n◎年\u3000\u3000代　" + data['year']
    if (data['country'] and len(data['country']) > 0) :
        douban_info += "\n◎产\u3000\u3000地　" + " / ".join(data['country'])
    if (data['genre'] and len(data['genre']) > 0):
        douban_info += "\n◎类\u3000\u3000别　" + " / ".join(data['genre'])
    if (data['language'] and len(data['language']) > 0) :
        douban_info += "\n◎语\u3000\u3000言　" + " / ".join(data['language'])
    if (data['release'] and len(data['release']) > 0) :
        douban_info += "\n◎上映日期　" + " / ".join(data['release'])
    if (data['firstRelease'] and len(data['firstRelease']) > 0) :
        douban_info += "\n◎首\u3000\u3000播　" + " / ".join(data['firstRelease'])
    if (data['num']) :
        douban_info += "\n◎集\u3000\u3000数　" + data['num']
    if (data['imdbRating']) :
        douban_info += "\n◎IMDb评分  " + data['imdbRating'] + "/10 from " + data['imdbVotes'] + " users"
    if (data['imdbUrl']) :
        douban_info += "\n◎IMDb链接  " + data['imdbUrl']
    if (data['rating']) :
        douban_info += "\n◎豆瓣评分　" + data['rating'] + "/10 from " + data['votes'] + " users";
    if (data['url']) :
        douban_info += "\n◎豆瓣链接　" + data['url']
    if (data['runtime'] and len(data['runtime']) > 0) :
        douban_info += "\n◎片　　长　" + " / ".join(data['runtime'])

    if (data['director'] and len(data['director']) > 0) :
        for i in range (len(data['director'])):
            if i==0:
                douban_info += "\n◎导　　演　" + (data['director'][i]['name'])
            else:
                douban_info += "\n　　　　　  " + (data['director'][i]['name'])

    if (data['writer'] and len(data['writer']) > 0) :
        for i in range (len(data['writer'])):
            if i==0:
                douban_info += "\n◎编　　剧　" + (data['writer'][i]['name'])
            else:
                douban_info += "\n　　　　　  " + (data['writer'][i]['name'])

    if (data['cast'] and len(data['cast']) > 0) :
        for i in range (len(data['cast'])):
            if i==0:
                douban_info += "\n◎主　　演　" + (data['cast'][i]['name'])
            else:
                douban_info += "\n　　　　　  " + (data['cast'][i]['name'])

    if (data['tags'] and len(data['tags']) > 0) :
        douban_info += "\n\n\n◎标　　签　" + " | ".join(data['tags'])
    if (data['plot']) :
        douban_info=douban_info[0:douban_info.find('<a')]
        plotstr=data['plot']
        plotstr=plotstr[0:plotstr.find('<a')]
        douban_info += "\n\n◎简　　介　" + "\n\n " +(plotstr)

    if (data['awards'] and len(data['awards']) > 0) :
        awardstr=''
        for item in data['awards']:
            awardstr=awardstr+"\n\n　　" + item['title'];
            for itemc in item['content']:
                awardstr=awardstr+"\n　　" + itemc
        douban_info += "\n\n◎获奖情况　" + awardstr

    douban_info =douban_info+ "\n\n"
    return douban_info


def doubaninfo(doubanurl):
    res=None
    trynum=0
    while res==None:
        trynum=trynum+1
        if trynum>10:
            print('获取失败')
            return 
        res=ptgen_douban_info(doubanurl)
        if res==None:
            res=lemon_douban_info(doubanurl)
        if res==None:
            time.sleep(3)
    print('\n'+res)
    return 







from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper

def ssd_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://springsunday.net/takeupload.php"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    #选择类型
    if 'anime' in file1.pathinfo.type.lower():
        select_type='504'
    elif 'tv' in file1.pathinfo.type.lower():
        select_type='502'
    elif 'movie' in file1.pathinfo.type.lower():
        select_type='501'
    elif 'show' in file1.pathinfo.type.lower():
        select_type='505'
    elif 'doc' in file1.pathinfo.type.lower():
        select_type='503'
    elif 'sport' in file1.pathinfo.type.lower():
        select_type='506'
    elif 'mv' in file1.pathinfo.type.lower():
        select_type='507'
    elif 'music' in file1.pathinfo.type.lower():
        select_type='508'
    else:
        select_type='509'
    logger.info('已成功填写类型为'+file1.pathinfo.type)


    #选择来源 
    if 'remux' in file1.type.lower():
        medium_sel='4'
    elif 'bdrip' in file1.type.lower():
        medium_sel='6'
    elif file1.type=='WEB-DL':
        medium_sel='7'
    elif 'webrip' in file1.type.lower():
        medium_sel='8'
    elif file1.type=='HDTV':
        medium_sel='5'
    elif 'tvrip' in file1.type.lower():
        medium_sel='9'
    elif 'dvdrip' in file1.type.lower():
        medium_sel='10'
    elif 'dvd' in file1.type.lower():
        medium_sel='3'
    else:
        medium_sel='12'
    logger.info('已成功选择质量为'+file1.type)



    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='2'
    elif file1.Video_Format=='x264':
        codec_sel='2'
    elif file1.Video_Format=='H265':
        codec_sel='1'
    elif file1.Video_Format=='x265':
        codec_sel='1'
    else:
        codec_sel='2'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择音频编码
    if file1.Audio_Format.upper()=='AAC':
        audiocodec_sel='5'
    elif 'DTS-HDMA' in file1.Audio_Format.upper() or 'DTS-HD MA' in file1.Audio_Format.upper():
        audiocodec_sel='1'
    elif 'TrueHD Atmos' in file1.Audio_Format.upper():
        audiocodec_sel='2'
    elif 'LPCM' in file1.Audio_Format.upper():
        audiocodec_sel='6'
    elif 'TrueHD' in file1.Audio_Format.upper():
        audiocodec_sel='2'
    elif 'FLAC' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    elif 'APE' in file1.Audio_Format.upper():
        audiocodec_sel='8'
    elif 'MP3' in file1.Audio_Format.upper():
        audiocodec_sel='10'
    elif 'AC3' in file1.Audio_Format.upper() or 'AC-3' in file1.Audio_Format.upper() or 'DD' in file1.Audio_Format.upper():
        audiocodec_sel='4'
    elif 'DTS:X' in file1.Audio_Format.upper() or 'DTS-X' in file1.Audio_Format.upper():
        audiocodec_sel='3'
    elif 'DTS' in file1.Audio_Format.upper():
        audiocodec_sel='3'
    elif 'WAV' in file1.Audio_Format.upper():
        audiocodec_sel='9'
    elif 'M4A' in file1.Audio_Format.upper():
        audiocodec_sel='10'
    else:
        audiocodec_sel='10'
    logger.info('已成功选择音频编码为'+file1.Audio_Format.upper())

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='1'
    elif '2160' in file1.standard_sel:
        standard_sel='1'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='2'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='3'
    elif '720' in file1.standard_sel:
        standard_sel='4'
    elif '480' in file1.standard_sel:
        standard_sel='5'
    else:
        standard_sel='2'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    
    #选择地区
    if file1.country!='' :
        if '大陆' in file1.country:
            source_sel='1'
            logger.info('国家信息已选择'+file1.country)
        elif '香港' in file1.country:
            source_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '台湾' in file1.country:
            source_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '美国' in file1.country:
            source_sel='9'
            logger.info('国家信息已选择'+file1.country)
        elif '英国' in file1.country:
            source_sel='9'
            logger.info('国家信息已选择'+file1.country)
        elif '法国' in file1.country:
            source_sel='9'
            logger.info('国家信息已选择'+file1.country)
        elif '韩国' in file1.country:
            source_sel='10'
            logger.info('国家信息已选择'+file1.country)
        elif '日本' in file1.country:
            source_sel='10'
            logger.info('国家信息已选择'+file1.country)
        elif '印度' in file1.country:
            source_sel='3'
            logger.info('国家信息已选择'+file1.country)
        else:
            source_sel='3'
            logger.info('未找到资源国家信息，已选择Other')
    else:
        source_sel='10'
    logger.info('未找到资源国家信息，已默认日本')

    if file1.pathinfo.collection==1:
        pack='yes'
    else:
        pack='no'
    
    if 'ssd' in file1.pathinfo.exclusive:
        exclusive='yes'
    else:
        exclusive='no'

    if siteinfo.uplver==1:
        uplver='yes'
    else:
        uplver='no'

    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            

    other_data = {
            "name": file1.uploadname.replace('  ',' ').replace(' ','.'),
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "url": file1.doubanurl,
            "url_vimages": file1.screenshoturl.replace('[img]','').replace('[/img]',''),
            "Media_BDInfo": file1.mediainfo,
            "color": "0",
            "font": "0",
            "size": "0",
            "type": select_type,
            "medium_sel": medium_sel,
            "codec_sel": codec_sel,
            "audiocodec_sel": audiocodec_sel,
            "standard_sel": standard_sel,
            "source_sel" : source_sel,
            "uplver": uplver,
            "exclusive": exclusive,
            "pack": pack,
            }

    scraper=cloudscraper.create_scraper()
    r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


import json
from pathlib import Path
from typing import Optional
from urllib.parse import urlparse
import requests
from loguru import logger

def smms_upload(imgpath: str, api_key: str):
    img  = Path(imgpath)
    headers = {'Authorization': api_key}
    files = {'smfile': open(img, 'rb'), 'format': 'json'}
    try:
        #req = requests.post('https://sm.ms/api/v2/upload', headers=headers, files=files)
        req = requests.post('https://smms.app/api/v2/upload', headers=headers, files=files)
    except Exception as r:
        logger.warning('requests 获取失败，原因: %s' %(r))
        return None
    try:
        res = req.json()
    except json.decoder.JSONDecodeError:
        logger.warning('返回结果获取失败')
        res = {}
    if not req.ok:
        logger.warning(
            f"上传图片失败: HTTP {req.status_code}, reason: {req.reason} "
            f"{res.get('msg') if 'msg' in res else ''}")
        return None
    if not res.get('success') and res.get('code') != 'image_repeated':
        logger.warning(f"上传图片失败: [{res.get('code')}]{res.get('message')}")
        return None
    if res.get('code') == 'image_repeated':
        return res.get('images')
    if 'data' not in res or 'url' not in res['data']:
        logger.warning(f"图片直链获取失败")
        return None
    return res['data']['url']

def smms_upload_files(imgpaths: list, api_key: str, form='img'):
    liststr=''
    imgnum=0
    for imgpath in imgpaths:
        imgnum=imgnum+1
        trynum=0
        success=0
        imgstr=''
        while success==0 and trynum<5:
            trynum=trynum+1
            try:
                imgstr=smms_upload(imgpath,api_key)
                success=1
            except Exception as r:
                success=0
                logger.warning('SMMS第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...原因: %s' %(r))
            if imgstr==None:
                success=0
                logger.warning('SMMS第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...')
        if success==1:
            if form.lower()=='img':
                liststr=liststr+imgstr+'\n'
            elif form.lower()=='bbcode':
                liststr=liststr+'[img]'+imgstr+'[/img]\n'
            else:
                liststr=liststr+imgstr+'\n'
            logger.info('SMMS第'+str(imgnum)+'张图片上传成功！')
        else:
            logger.warning('SMMS第'+str(imgnum)+'张图片'+imgpath+'上传失败')
    return liststr.strip()

#p1="/Users/moyu/Downloads/在线视频十大品牌-视频app排行榜-视频网站排行榜-买购品牌网 (2).png"
#p2="/Users/moyu/Downloads/zhizhu.jpg"
#imgpaths=[p1,p2]
#key='7ubkPohmLV4LcAUjB5FsDmI0DWvaPo28'
#print(smms_upload(p,key))
#print(smms_upload_files(imgpaths,key,'bbcode'))



from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper

def mteam_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://kp.m-team.cc/takeupload.php"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    #选择类型
    if 'anime' in file1.pathinfo.type.lower():
        select_type='405'
    elif 'tv' in file1.pathinfo.type.lower() and file1.pathinfo.collection==1:
        if '480' in file1.standard_sel:
            select_type='403'
        else:
            select_type='402'
    elif 'movie' in file1.pathinfo.type.lower():
        if 'remux' in file1.type.lower():
            select_type='439'
        elif 'dvd' in file1.type.lower() and 'iso' in file1.type.lower():
            select_type='420'
        elif 'blu' in file1.type.lower() or 'bdmv' in file1.type.lower() or 'iso' in file1.type.lower():
            select_type='421'
        elif '480' in file1.standard_sel:
            select_type='401'
        else:
            select_type='419'
        select_type='401'
    elif 'show' in file1.pathinfo.type.lower():
        select_type='402'
    elif 'doc' in file1.pathinfo.type.lower():
        select_type='404'
    elif 'mv' in file1.pathinfo.type.lower():
        select_type='406'
    elif 'sport' in file1.pathinfo.type.lower():
        select_type='407'
    elif 'music' in file1.pathinfo.type.lower():
        select_type='434'
    else:
        select_type='405'
    logger.info('已成功填写类型为'+file1.pathinfo.type)

    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='1'
    elif file1.Video_Format=='x264':
        codec_sel='1'
    elif file1.Video_Format=='H265':
        codec_sel='16'
    elif file1.Video_Format=='x265':
        codec_sel='16'
    else:
        codec_sel='1'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='6'
    elif '2160' in file1.standard_sel:
        standard_sel='6'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='1'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='2'
    elif '720' in file1.standard_sel:
        standard_sel='3'
    elif '480' in file1.standard_sel:
        standard_sel='5'
    else:
        standard_sel='1'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    
    #选择地区
    if not file1.country=='':
        if '大陆' in file1.country:
            processing_sel='1'
            logger.info('国家信息已选择'+file1.country)
        elif '香港' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '台湾' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '美国' in file1.country:
            processing_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '英国' in file1.country:
            processing_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '法国' in file1.country:
            processing_sel='6'
            logger.info('国家信息已选择'+file1.country)
        elif '韩国' in file1.country:
            processing_sel='5'
            logger.info('国家信息已选择'+file1.country)
        elif '日本' in file1.country:
            processing_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '印度' in file1.country:
            processing_sel='6'
            logger.info('国家信息已选择'+file1.country)
        else:
            processing_sel='6'
            logger.info('未找到资源国家信息，已选择其他')
    else:
        processing_sel='4'
        logger.info('未找到资源国家信息，已默认日本')

    #选择制作组
    if 'MTeam' in file1.sub.upper():
        team_sel='9'
    elif 'LowPower-Raws' in file1.sub.upper():
        team_sel='22'
    else:
        team_sel='0'
    logger.info('制作组已成功选择为'+file1.sub)

    
    if siteinfo.uplver==1:
        uplver='yes'
    else:
        uplver='no'

    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            
    other_data = {
            "type": select_type,
            "name": file1.uploadname,
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "url": file1.imdburl,
            "color": "0",
            "font": "0",
            "size": "0",
            "descr": file1.content,
            "codec_sel": codec_sel,
            "standard_sel": standard_sel,
            "processing_sel" : processing_sel,
            "team_sel": '8',
            "uplver": uplver,
            }

    if '国' in file1.language or '中' in file1.language:
        other_data['l_dub']='yes'
        logger.info('已选择国语')
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        other_data['l_sub']='yes'
        logger.info('已选择中字')
    scraper=cloudscraper.create_scraper()
    r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


import os
import yaml
from loguru import logger
def readyaml(file):
    logger.info('正在读取yaml...')
    f=open(file, encoding='utf-8')
    audata = yaml.load(f, Loader=yaml.FullLoader)
    f.close()
    logger.info('读取yaml完毕')
    #au_data['yaml_path']=file
    newfile=file+'.bak'
    write_yaml(audata,newfile)
    return audata
    
def write_yaml(au_data,file=''):
    mod =''
    if file=='' and 'yaml_path' in au_data:
        file=au_data.pop('yaml_path')
    if 'mod' in au_data    :
        mod =au_data.pop('mod')
    if file=='':
        logger.error('未找到yaml文件信息,无法写入文件')
        raise ValueError ('未找到yaml文件信息,无法写入文件')

    logger.info('正在更新yaml中，请勿中途终止程序。如果特殊原因终止程序导致yaml文件内容丢失，请前往au.yaml.bak文件内容中找回')
    f=open(file, "w", encoding='utf-8')
    f.write(yaml.dump(au_data, allow_unicode=True, sort_keys=False))
    f.close()
    logger.info('更新yaml完毕')

    if not file=='' and not '.bak' in file:
        au_data['yaml_path']=file
    if not mod=='':
        au_data['mod']=mod



import json
from pathlib import Path
import requests
from urllib.parse import urlparse
from loguru import logger

def ptpimg_upload(imgpath: str, api_key: str):
    img  = Path(imgpath)
    data = {'api_key': api_key}
    files = {'file-upload[0]': open(img, 'rb')}
    try:
        req = requests.post('https://ptpimg.me/upload.php', data=data, files=files)
    except Exception as r:
        logger.warning('requests 获取失败，原因: %s' %(r))
        return None
    try:
        res = req.json()
    except json.decoder.JSONDecodeError:
        res = {}
    if not req.ok:
        logger.warning(req.content)
        logger.warning(f"上传图片失败: HTTP {req.status_code}, reason: {req.reason}")
        return None
    if len(res) < 1 or 'code' not in res[0] or 'ext' not in res[0]:
        logger.warning(f"图片直链获取失败")
        return None
    return f"https://ptpimg.me/{res[0].get('code')}.{res[0].get('ext')}"


def ptpimg_upload_files(imgpaths: list, api_key: str, form='img'):
    liststr=''
    imgnum=0
    for imgpath in imgpaths:
        imgnum=imgnum+1
        trynum=0
        success=0
        imgstr=''
        while success==0 and trynum<5:
            trynum=trynum+1
            try:
                imgstr=ptpimg_upload(imgpath,api_key)
                success=1
            except Exception as r:
                success=0
                logger.warning('PTPIMG第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，失败原因: %s\n正在重试...' %(r))
            if imgstr==None:
                success=0
                logger.warning('PTPIMG第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...')
        if success==1:
            if form.lower()=='img':
                liststr=liststr+imgstr+'\n'
            elif form.lower()=='bbcode':
                liststr=liststr+'[img]'+imgstr+'[/img]\n'
            else:
                liststr=liststr+imgstr+'\n'
            logger.info('PTPIMG第'+str(imgnum)+'张图片上传成功！')
        else:
            logger.warning('PTPIMG第'+str(imgnum)+'张图片'+imgpath+'上传失败')
            return ''
    return liststr.strip()
    

#p1="/Users/moyu/Downloads/在线视频十大品牌-视频app排行榜-视频网站排行榜-买购品牌网 (2).png"
#p2="/Users/moyu/Downloads/zhizhu.jpg"
#imgpaths=[p1,p2]
#key='de2a51b1-d5fc-45d0-8429-9c53a0c36468'
#print(ptpimg_upload(p,key))
#print(ptpimg_upload_files(imgpaths,key,'bbcode'))








from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper

def wintersakura_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://wintersakura.net/takeupload.php"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    #选择类型
    if 'anime' in file1.pathinfo.type.lower():
        select_type='413'
    elif 'tv' in file1.pathinfo.type.lower() and file1.pathinfo.collection==1:
        if '大陆' in file1.country or '香港' in file1.country or '台湾' in file1.country:
            select_type='417'
        else:
            select_type='402'
    elif 'tv' in file1.pathinfo.type.lower() and file1.pathinfo.collection==0:
        if '大陆' in file1.country or '香港' in file1.country or '台湾' in file1.country:
            select_type='402'
        else:
            select_type='416'
    elif 'movie' in file1.pathinfo.type.lower():
        select_type='401'
    elif 'show' in file1.pathinfo.type.lower():
        select_type='403'
    elif 'doc' in file1.pathinfo.type.lower():
        select_type='410'
    elif 'mv' in file1.pathinfo.type.lower():
        select_type='406'
    elif 'sport' in file1.pathinfo.type.lower():
        select_type='407'
    else:
        select_type='409'
    logger.info('已成功填写类型为'+file1.pathinfo.type)

    #选择质量
    if file1.type=='WEB-DL':
        medium_sel='21'
    elif 'rip' in file1.type.lower() or file1.type=='bluray'  :
        medium_sel='15'
    elif file1.type=='HDTV':
        medium_sel='16'
    elif file1.type=='Remux':
        medium_sel='14'
    else:
        medium_sel='15'
    logger.info('已成功选择质量为'+file1.type)
   


    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='6'
    elif file1.Video_Format=='x264':
        codec_sel='8'
    elif file1.Video_Format=='H265':
        codec_sel='9'
    elif file1.Video_Format=='x265':
        codec_sel='7'
    else:
        codec_sel='6'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择音频编码
    if file1.Audio_Format.upper()=='AAC':
        audiocodec_sel='19'
    elif 'DTS-HDMA' in file1.Audio_Format.upper() or 'DTS-HD MA' in file1.Audio_Format.upper():
        audiocodec_sel='8'
    elif 'TrueHD Atmos' in file1.Audio_Format.upper():
        audiocodec_sel='10'
    elif 'LPCM' in file1.Audio_Format.upper():
        audiocodec_sel='14'
    elif 'TrueHD' in file1.Audio_Format.upper():
        audiocodec_sel='12'
    elif 'FLAC' in file1.Audio_Format.upper():
        audiocodec_sel='15'
    elif 'APE' in file1.Audio_Format.upper():
        audiocodec_sel='16'
    elif 'MP3' in file1.Audio_Format.upper():
        audiocodec_sel='17'
    elif 'AC3' in file1.Audio_Format.upper() or 'AC-3' in file1.Audio_Format.upper() or 'DD' in file1.Audio_Format.upper():
        audiocodec_sel='20'
    elif 'DTS:X' in file1.Audio_Format.upper() or 'DTS-X' in file1.Audio_Format.upper():
        audiocodec_sel='13'
    elif 'DTS' in file1.Audio_Format.upper():
        audiocodec_sel='13'
    elif 'WAV' in file1.Audio_Format.upper():
        audiocodec_sel='23'
    elif 'M4A' in file1.Audio_Format.upper():
        audiocodec_sel='21'
    else:
        audiocodec_sel='19'
    logger.info('已成功选择音频编码为'+file1.Audio_Format.upper())

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='5'
    elif '2160' in file1.standard_sel:
        standard_sel='5'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='1'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='2'
    elif '720' in file1.standard_sel:
        standard_sel='3'
    elif '480' in file1.standard_sel:
        standard_sel='4'
    else:
        standard_sel='1'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    

    #选择制作组
    if 'wsub' in file1.sub.lower():
        team_sel='12'
    elif 'sakura academic' in file1.sub.lower():
        team_sel='19'
    elif 'wsdiy' in file1.sub.lower():
        team_sel='11'
    elif 'wscode' in file1.sub.lower():
        team_sel='16'
    elif 'sakuraweb' in file1.sub.lower():
        team_sel='18'
    elif 'bhd' in file1.sub.lower():
        team_sel='9'
    elif 'chd' in file1.sub.lower():
        team_sel='2'
    elif 'hds' in file1.sub.lower():
        team_sel='1'
    elif 'hdc' in file1.sub.lower():
        team_sel='14'
    elif 'mteam' in file1.sub.lower():
        team_sel='13'
    elif 'ttg' in file1.sub.lower():
        team_sel='15'
    elif 'cmct' in file1.sub.lower():
        team_sel='6'
    elif 'frds' in file1.sub.lower():
        team_sel='7'
    elif 'pter' in file1.sub.lower():
        team_sel='8'
    elif 'tjupt' in file1.sub.lower():
        team_sel='17'
    else:
        team_sel='5'
    logger.info('制作组已成功选择为'+file1.sub)
    
    if 'sakura academic' in file1.sub.lower():
        tags.append(15)
        logger.info('已选择Sakura Academic')
    if 'sakuraweb' in file1.sub.lower():
        tags.append(14)
        logger.info('已选择Sakura WEB')
    if 'wsub' in file1.sub.lower():
        tags.append(13)
        logger.info('已选择Sakura SUB')
    if 'sakura' in file1.sub.lower() or 'wsub' in file1.sub.lower():
        tags.append(3)
        logger.info('已选择官方标签')
    if 'wintersakura' in file1.pathinfo.exclusive :
        tags.append(1)
        logger.info('已选择禁转')
    if '国' in file1.language or '中' in file1.language:
        tags.append(5)
        logger.info('已选择国语')
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        tags.append(6)
        logger.info('已选择中字')
    if file1.pathinfo.transfer==0:
        tags.append(8)
        logger.info('已选择原创')

    
    tags=list(set(tags))
    tags.sort()
    
    if siteinfo.uplver==1:
        uplver='yes'
    else:
        uplver='no'

    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            

    other_data = {
            "name": file1.uploadname,
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "pt_gen": file1.doubanurl,
            "url" : file1.imdburl,
            "color": "0",
            "font": "0",
            "size": "0",
            "descr": file1.content,
            "type": select_type,
            "medium_sel": medium_sel,
            "codec_sel": codec_sel,
            "audiocodec_sel": audiocodec_sel,
            "standard_sel": standard_sel,
            "team_sel": team_sel,
            "uplver": uplver,
            "tags[]": tags,
            }

    scraper=cloudscraper.create_scraper()
    r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


from loguru import logger
from upload_machine.utils.para_ctrl.readyaml import write_yaml
import os
from upload_machine.utils.pathinfo.pathinfo import findnum
from upload_machine.utils.mediafile.mediafile import mediafile
from upload_machine.utils.uploader.auto_upload import auto_upload
from shutil import move
from qbittorrentapi import Client
import time
import datetime


def get_newhash(qbinfo):
    logger.info('正在查找最新发布的种子的hash...')
    logger.info('正在登录Qbittorrent WEBUI页面...')
    try:
        client = Client(host=qbinfo['qburl'],username=qbinfo['qbwebuiusername'],password=qbinfo['qbwebuipassword'])
    except Exception as r:
        logger.warning('Qbittorrent WEBUI登录失败，错误信息: %s' %(r))
        logger.warning('获取最新种子hash失败')
        return ''
    logger.info('正在登录Qbittorrent WEBUI账号..')
    try:
        client.auth_log_in()
    except Exception as r:
        logger.warning('Qbittorrent WEBUI信息错误，登录失败，请检查au.yaml文件里的url、用户名、密码，错误信息: %s' %(r))
        logger.warning('获取最新种子hash失败')
        return ''
    addtime=0
    torrentlist=client.torrents.info()
    for item in torrentlist:
        if item.added_on>addtime:
            addtime=item.added_on
            to=item
    return to._torrent_hash

def start_hash(qbinfo,hashlist):
    if hash=='':
        logger.warning('hash为空，并没有开始任何种子')
        return 
    logger.info('正在查找最新发布的种子的hash...')
    logger.info('正在登录Qbittorrent WEBUI页面...')
    try:
        client = Client(host=qbinfo['qburl'],username=qbinfo['qbwebuiusername'],password=qbinfo['qbwebuipassword'])
    except Exception as r:
        logger.warning('Qbittorrent WEBUI登录失败,错误信息: %s' %(r))
        return 
    logger.info('正在登录Qbittorrent WEBUI账号..')
    try:
        client.auth_log_in()
    except Exception as r:
        logger.warning('Qbittorrent WEBUI信息错误，登录失败，请检查au.yaml文件里的url、用户名、密码，错误信息: %s' %(r))
        return 
    for tohash in hashlist:
        try:
            client.torrents_resume(torrent_hashes=tohash)
        except Exception as r:
            logger.warning('开始种子发生错误,错误信息: %s' %(r))
    






def seedmachine_single(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
    '''
    para:
        pathinfo
        sites 
        pathyaml 用于更新yaml中发布信息
        basic
        qbinfo  
    '''
    logger.info('正在发布路径'+pathinfo.path+'下资源')
    log_error=''
    log_succ=''
    logstr=''
    errornum=0
    succnum=0
    for pathep in pathinfo.eps:

        #判断此集有没有站点要发布,此集合收纳还没有发布过本集的站点
        site_upload=[]
        for siteitem in sites:
            #发布过此集的站点略过
            if sites[siteitem].enable==1 and not( eval('pathinfo.'+siteitem+'_max_done==10000')) and not eval('pathep in pathinfo.'+siteitem+'_done'):
                site_upload.append(sites[siteitem])

        #如果没有站点要发布就略过本集
        if len(site_upload)==0:
            continue

        ls = os.listdir(pathinfo.path)
        filepath=''
        for i in ls:
            c_path=os.path.join(pathinfo.path, i)
            if (os.path.isdir(c_path)) or (i.startswith('.')) or (not(  os.path.splitext(i)[1].lower()== ('.mp4') or os.path.splitext(i)[1].lower()== ('.mkv')  or os.path.splitext(i)[1].lower()== ('.avi') or os.path.splitext(i)[1].lower()== ('.ts')    )):
                continue
            if int(findnum(i)[0])==pathep:
                filepath=c_path
                break
        move_suc=0
        move_newpath=''
        move_oldpath=''
        
        if filepath=='' and pathinfo.zeroday_name!='':
            zeroday_path=os.path.join(pathinfo.path,pathinfo.zeroday_name)
            ls = os.listdir(zeroday_path)
            filepath=''
            for i in ls:
                c_path=os.path.join(zeroday_path, i)
                if (os.path.isdir(c_path)) or (i.startswith('.')) or (not(  os.path.splitext(i)[1].lower()== ('.mp4') or os.path.splitext(i)[1].lower()== ('.mkv')  or os.path.splitext(i)[1].lower()== ('.avi') or os.path.splitext(i)[1].lower()== ('.ts')    )):
                    continue
                if int(findnum(i)[0])==pathep:
                    move_oldpath=os.path.dirname(c_path)
                    filepath=move(c_path,pathinfo.path)
                    move_newpath=filepath
                    move_suc=1
                    break
    
        if filepath=='':
            logger.error('未找到文件夹'+pathinfo.path+'下第'+str(pathep)+'集资源')
            raise ValueError ('未找到文件夹'+pathinfo.path+'下第'+str(pathep)+'集资源')

        #获取file全部信息
        file1=mediafile(filepath,pathinfo,basic,imgdata)
        if not pathinfo.imdb_url=='' and pathyaml['imdb_url']==None:
            pathyaml['imdb_url']=pathinfo.imdb_url
        
        
        
        logger.info('正在发布路径'+pathinfo.path+'下第'+str(pathep)+'集资源:'+filepath)
        logger.info('正在抓取资源信息,请稍后...')
        file1.getfullinfo()
        for siteitem in site_upload:
            if siteitem.enable==0:
                continue
            logger.info('正在'+siteitem.sitename+'站点发布路径'+pathinfo.chinesename+'第'+str(pathep)+'集资源')
            upload_success=False
            uploadtime=0
            #用模板获取mediainfo
            file1.updatemediainfo(siteitem.mediainfo_template_file)
            while upload_success==False and uploadtime<3:
                uploadtime=uploadtime+1
                logger.info('第'+str(uploadtime)+'次尝试发布')

                try:
                    upload_success,logstr=auto_upload(siteitem,file1,basic['record_path'],qbinfo,basic,hashlist)
                except Exception as r:
                    logger.warning('发布资源发生错误，错误信息: %s' %(r))
                    upload_success=False

                if not upload_success:
                    logger.warning(siteitem.sitename+'第'+str(uploadtime)+'次发布任务失败')
                    logger.warning(logstr)
                    file1.mktorrent()

            if not upload_success:
                logger.warning(siteitem.sitename+'发布任务失败，本站暂停发种')
                siteitem.enable=0
                errornum=errornum+1
                log_error=log_error+str(errornum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
                logger.warning(logstr)
            elif '已存在' in  logstr:
                errornum=errornum+1
                log_error=log_error+str(errornum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
                logger.warning(logstr)
                #记录已发布的种子
                exec('pathinfo.'+siteitem.sitename+'_done.append(pathep)')
                exec('pathinfo.'+siteitem.sitename+'_done.sort()')
                exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
            else:
                succnum=succnum+1
                log_succ=log_succ+str(succnum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
                logger.info(logstr)
                #记录已发布的种子
                exec('pathinfo.'+siteitem.sitename+'_done.append(pathep)')
                exec('pathinfo.'+siteitem.sitename+'_done.sort()')
                exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
                #deletetorrent(basic['screenshot_path'])
            #a=input('check')
            
        del(file1)
        if move_suc==1 and os.path.exists(move_newpath) and os.path.exists(move_oldpath):
            logger.info('正在尝试将文件：'+move_newpath+'移动回原位：'+move_oldpath)
            try:
                move_newpath=move(move_newpath,move_oldpath)
                move_suc=0
            except Exception as r:
                logger.warning('移动文件'+move_newpath+'到'+move_oldpath+'链接失败，原因: %s' %(r))
            
    logger.info('路径'+pathinfo.path+'下资源已全部发布完毕')
    return log_error,log_succ

def seedmachine(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
    '''
    para:
        pathinfo
        sites 
        pathyaml 用于更新yaml中发布信息
        basic
        qbinfo  
    '''
    logger.info('正在发布路径'+pathinfo.path+'下资源')
    log_error=''
    log_succ=''
    logstr=''
    errornum=0
    succnum=0
    site_upload=[]
    for siteitem in sites:
        #发布过此集的站点略过
        if sites[siteitem].enable==1 and not( eval('pathinfo.'+siteitem+'_max_done==10000')) and not eval('-1 in pathinfo.'+siteitem+'_done'):
            site_upload.append(sites[siteitem])

    #如果没有站点要发布就略过本集
    if len(site_upload)==0:
        logger.info('路径'+pathinfo.path+'下资源已全部发布完毕')
        return log_error,log_succ


    #获取file全部信息
    file1=mediafile(pathinfo.path,pathinfo,basic,imgdata)
    if not pathinfo.imdb_url=='' and pathyaml['imdb_url']==None:
        pathyaml['imdb_url']=pathinfo.imdb_url

    logger.info('正在'+siteitem+'站点发布路径'+pathinfo.path+'下资源')
    logger.info('正在抓取资源信息,请稍后...')
    file1.getfullinfo()

    for siteitem in site_upload:
        if siteitem.enable==0:
            continue
        logger.info('正在'+siteitem.sitename+'站点发布'+pathinfo.chinesename+'资源')
        upload_success=False
        uploadtime=0
        #用模板获取mediainfo
        file1.updatemediainfo(siteitem.mediainfo_template_file)
        while upload_success==False and uploadtime<3:
            uploadtime=uploadtime+1
            logger.info('第'+str(uploadtime)+'次尝试发布')
            print("正在准备登录"+siteitem.sitename)


            upload_success,logstr=auto_upload(siteitem,file1,basic['record_path'],qbinfo,basic,hashlist)
            if not upload_success:
                logger.warning(siteitem.sitename+'第'+str(uploadtime)+'次发布任务失败')
                logger.warning(logstr)
                #file1.mktorrent()

        if not upload_success:
            logger.warning(siteitem.sitename+'发布任务失败，本站暂停发种')
            siteitem.enable=0
            errornum=errornum+1
            log_error=log_error+str(errornum)+':\t'+siteitem.sitename+'  \t'+logstr+'\n'
            logger.warning(logstr)
        elif '已存在' in  logstr:
            errornum=errornum+1
            log_error=log_error+str(errornum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
            logger.warning(logstr)
            #记录已发布的种子
            exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
            exec('pathinfo.'+siteitem.sitename+'_done.sort()')
            exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
        else:
            succnum=succnum+1
            log_succ=log_succ+str(succnum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
            logger.info(logstr)
            #记录已发布的种子
            exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
            exec('pathinfo.'+siteitem.sitename+'_done.sort()')
            exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
            #deletetorrent(basic['screenshot_path'])
        #a=input('check')
            
    del(file1)  
    logger.info('路径'+pathinfo.path+'下资源已全部发布完毕')
    return log_error,log_succ



def start_machine(pathlist,sites,yamlinfo):
    log_allsucc=''
    log_allerror=''
    hashlist=[]
    for path in pathlist:
        if path.enable==0:
            logger.info('路径'+path.path+'的enable被设置为0，已忽略')
            continue
        if (path.type=='anime' or path.type=='tv') and path.collection==0:
            log_error,log_succ=seedmachine_single(path,sites,yamlinfo['path info'][path.pathid],yamlinfo['basic'],yamlinfo['qbinfo'],yamlinfo['image hosting'],hashlist)
        else:
            log_error,log_succ=seedmachine(path,sites,yamlinfo['path info'][path.pathid],yamlinfo['basic'],yamlinfo['qbinfo'],yamlinfo['image hosting'],hashlist)
        write_yaml(yamlinfo)
        if not log_succ=='':
            log_allsucc=log_allsucc+log_succ+'\n'
            logger.info(log_succ)
        print('\n')
        if not log_error=='':
            log_allerror=log_allerror+log_error+'\n'
            logger.error(log_error)

    if 'start' in yamlinfo['qbinfo'] and  yamlinfo['qbinfo']['start']==1:
        logger.info('检测到需要开始种子，正在开始种子...')
        try:
            start_hash(yamlinfo['qbinfo'],hashlist)
        except Exception as r:
            logger.warning('开始种子发生错误,错误信息: %s' %(r))




    print('\n\n以下种子已成功发布:')
    print('*'*100)
    #print(log_allsucc.strip())
    print('\033[1;35m'+log_allsucc.strip()+'\033[0m')
    print('*'*100+'\n\n')
    

    logger.trace('\n\n以下种子已成功发布:')
    logger.trace('*'*100)
    logger.trace(log_allsucc.strip())
    logger.trace('*'*100+'\n\n')

    print('以下种子发布失败:')
    print('&'*100)
    if log_allerror.strip()=='':
        print('\033[1;31;40m 无 \033[0m')
    else:
        print('\033[1;31;40m'+log_allerror.strip()+'\033[0m')
    #print(log_allerror.strip())
    print('&'*100+'\n\n')

    logger.trace('以下种子发布失败:')
    logger.trace('&'*100)
    logger.trace(log_allerror.strip())
    logger.trace('&'*100+'\n\n')





import json
from pathlib import Path
from typing import Optional
from urllib.parse import urlparse
import requests
from bs4 import BeautifulSoup
from loguru import logger


def GetPicUrl(url:str):
    html_doc = requests.get(url).content.decode()
    soup = BeautifulSoup(html_doc, 'html.parser')
    pic_list = soup.find_all('img')
    for item in pic_list:
        url = item.get('src')
        if 'fapping.empornium.sx/images/' in url:
        	return url
    return None

def femp_upload(imgpath: str):
    img  = Path(imgpath)
    files = {'ImageUp': open(img, 'rb')}
    data = {'doShort': 'false', 'resize': ''}
    try:
        req = requests.post('https://fapping.empornium.sx/upload.php', data=data , files=files)
    except Exception as r:
        logger.warning('requests 获取失败，原因: %s' %(r))
        return None
    try:
        res = req.json()
    except json.decoder.JSONDecodeError:
        logger.warning('返回结果获取失败')
        res = {}
    if not req.ok:
        logger.warning(
            f"上传图片失败: HTTP {req.status_code}, reason: {req.reason} "
            f"{res.get('errorMsg') if 'errorMsg' in res else ''}")
        return None

    if 'image_id_public' not in res or res['image_id_public']=='':
        logger.warning(f"上传图片失败: {res.get('errorMsg')}")
        return None
    picurl='https://fapping.empornium.sx/'+res['image_id_public']
    return GetPicUrl(picurl)

def femp_upload_files(imgpaths: list[str],form:str='img'):
    liststr=''
    imgnum=0
    for imgpath in imgpaths:
        imgnum=imgnum+1
        trynum=0
        success=0
        imgstr=''
        while success==0 and trynum<5:
            trynum=trynum+1
            try:
                imgstr=femp_upload(imgpath)
                success=1
            except Exception as r:
                success=0
                logger.warning('fapping_emp第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...原因: %s' %(r))
            if imgstr==None:
                success=0
                logger.warning('fapping_emp第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...')
        if success==1:
            if form.lower()=='img':
                liststr=liststr+imgstr+'\n'
            elif form.lower()=='bbcode':
                liststr=liststr+'[img]'+imgstr+'[/img]\n'
            else:
                liststr=liststr+imgstr+'\n'
            logger.info('fapping_emp第'+str(imgnum)+'张图片上传成功！')
        else:
            logger.warning('fapping_emp第'+str(imgnum)+'张图片'+imgpath+'上传失败')
    return liststr.strip()







from loguru import logger
from qbittorrentapi import Client
import time
import datetime
import os
from urllib.parse import urlparse
from bs4 import BeautifulSoup
import sys
import re
import qbittorrentapi
from http.cookies import SimpleCookie


def afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist):
    if r.status_code==200:
        logger.info('已发布成功')
    else:
        logger.warning('发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason))
        return False,fileinfo+' 发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason)
    String_url =finduploadurl(r)
    downloadurl=finddownloadurl(r)
    if downloadurl=='已存在':
        return True,fileinfo+'种子发布失败,失败原因:种子'+downloadurl+',当前网址:'+String_url
    recordupload(os.path.join(record_path,siteinfo.sitename+'_torrent.csv'),file1,String_url,downloadurl)
    if downloadurl !='':
        res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo,category=file1.pathinfo.category,hashlist=hashlist)
        if res:
            return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+String_url
        else:
            return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+String_url
    else:
        logger.warning('正在记录错误的请求返回值')
        errorfile=os.path.join(record_path,'errorhtml.html')
        f=open(errorfile,'w', encoding='utf-8')
        f.write(r.text)
        f.close()
        return False,fileinfo+'未找到下载链接,当前网址:'+String_url+' ,请求的返回值已保存至:'+errorfile

def cookies_raw2jar(raw: str) -> dict:
    """
    Arrange Cookies from raw using SimpleCookies
    """
    if not raw:
        raise ValueError("The Cookies is not allowed to be empty.")
    cookie = SimpleCookie(raw)
    return {key: morsel.value for key, morsel in cookie.items()}

def recordupload(torrent_file,file1,String_url,downloadurl):
    logger.info('正在记录发布的资源到'+torrent_file)
    if not os.path.exists(torrent_file):
        if 'win32' in sys.platform:
            f = open(torrent_file,'w+',encoding='utf-8-sig',errors='ignore')
        else:
            f = open(torrent_file,'w+',encoding='utf-8-sig')

        f.write('中文名,集数,发布日期,资源链接,资源下载链接\n0\n')
        f.close()

    if 'win32' in sys.platform:
        with open(torrent_file, 'r',encoding='utf-8-sig',errors='ignore') as f1:
            list1 = f1.readlines()
    else:
        with open(torrent_file, 'r') as f1:
            list1 = f1.readlines()
    while list1[-1].strip()=='':
        a=list1.pop(-1)
        del(a)
    
    try:
        num=int(list1[-1].replace(',','').strip())
        a=list1.pop(-1)
        del(a)
    except:
        num=0
    if len(list1)>0:
        list1[-1]=list1[-1].strip()+'\n'

    now = datetime.datetime.now()

    filestr=''.join(list1)
    newstr=''

    newstr=newstr+file1.chinesename.replace(',',' ')+','
    if not ('anime' in file1.pathinfo.type.lower() or 'tv' in file1.pathinfo.type.lower()) or file1.pathinfo.collection==0:
        newstr=newstr+file1.episodename.zfill(2)+','
    else:
        newstr=newstr+'第'+str(file1.pathinfo.min).zfill(2)+'-'+str(file1.pathinfo.max).zfill(2)+'集 合集,'
    newstr=newstr+str(now.year)+str(now.month).zfill(2)+str(now.day).zfill(2)+','
    newstr=newstr+str(String_url)+','
    newstr=newstr+str(downloadurl)+'\n'

    logger.debug(newstr)

    filestr=filestr+newstr+str(num+1)+'\n'
    if 'win32' in sys.platform:
        f = open(torrent_file,'w+',encoding='utf-8-sig',errors='ignore')
    else:
        f = open(torrent_file,'w+',encoding='utf-8-sig')
    f.write(filestr)
    f.close()
    logger.info('记录完毕')

def finduploadurl(res):
    logger.info('正在寻找发布页面链接')
    String_url = res.url
    if not('&uploaded' in String_url):
        logger.warning(String_url+'未找到发布页面网址')
        return '未找到发布页面网址'
    String_url =String_url.split('&uploaded')[0]
    return String_url


def finddownloadurl(res):
    logger.info('正在寻找页面下载链接')
    o = urlparse(res.url)
    o = o.scheme+'://'+o.hostname+'/download.php?'
    #白兔特判
    if 'hare' in o:
        link = re.findall('(https://club\.hares\.top/download\.php\?downhash=.*)\</p',res.text)
        if len(link)>0:
            return link[0]
        else:
            if '已存在' in res.text:
                logger.warning('该种子已存在')
                return '已存在'
            logger.warning('未找到下载链接')
            return ''
    #白兔特判结束
    soup = BeautifulSoup(res.text,'lxml')
    for a in soup.find_all('a'):
        link=''
        try:
            link = a['href']
        except:
            #logger.warning('该a标签未找到href属性')
            logger.trace('该a标签未找到href属性')
        if o in link:
            logger.info('成功获得下载链接'+link)
            return link

    for a in soup.find_all('a'):
        link=''
        try:
            link = a['href']
        except:
            logger.warning('该a标签未找到href属性')
        if len(re.findall(r'download.php\?id=[0-9]+&',link))>0:
            o = urlparse(res.url)
            if link.startswith('download.php'):
                link=o.scheme+'://'+o.hostname+'/'+link
            logger.info('成功获得下载链接'+link)
            return link

    logger.warning('未找到下载链接')
    if '已存在' in res.text:
        logger.warning('该种子已存在')
        return '已存在'
    return ''



def qbseed(url,filepath,qbinfo,is_skip_checking=False,is_paused=True,category=None,hashlist=[]):
    logger.info('正在添加资源到Qbittorrent,请稍等...')

    is_paused=True
    try:
        client = Client(host=qbinfo['qburl'],username=qbinfo['qbwebuiusername'],password=qbinfo['qbwebuipassword'])
    except:
        logger.warning('Qbittorrent WEBUI登录失败,将种子添加到QB任务失败')
        return False

    logger.info('正在登录Qbittorrent WEBUI')
    try:
        client.auth_log_in()
    except:
        logger.warning('Qbittorrent WEBUI信息错误，登录失败，请检查au.yaml文件里的url、用户名、密码')
        return False
    logger.info('成功登录Qbittorrent WEBUI')
    try:
        tor_num=len(client.torrents_info())
    except Exception as err:
        tor_num=0    
    tor_num_new=tor_num
    trynum=0
    while tor_num_new==tor_num:
        trynum=trynum+1
        if trynum>12:
            logger.warning('添加种子失败,种子下载链接为:'+url+'   请自行手动添加')
            return True
        logger.info('正在第'+str(trynum)+'次添加种子')
        try:
            res=client.torrents_add(urls=url,save_path=filepath,is_skip_checking=is_skip_checking,is_paused=is_paused,use_auto_torrent_management=None,category=category)
        except Exception as r:
            logger.warning('添加种子进入qb出错，错误信息: %s' %(r))
            continue
            #raise ValueError ('添加种子进入qbittorrent出错，程序结束')
        if 'Ok' in res:
            logger.info('返回值显示成功添加种子')
        else:
            logger.warning('添加种子失败，返回值为:'+str(res))
        time.sleep(1)
        try:
            tor_num_new=len(client.torrents_info())
        except Exception as r:
            tor_num_new=tor_num
            logger.warning('计算种子数量出错，错误信息: %s' %(r))
        if tor_num_new==tor_num:
            time.sleep(5)
            try:
                tor_num_new=len(client.torrents_info())
            except Exception as r:
                tor_num_new=tor_num
                logger.warning('计算种子数量出错，错误信息: %s' %(r))

    logger.info('已经成功添加种子')
    addtime=0
    to=None
    try:
        torrentlist=client.torrents.info()
    except Exception as r:
        torrentlist=[]
        logger.warning('获取种子信息出错，错误信息: %s' %(r))
    for item in torrentlist:
        if item.added_on>addtime:
            addtime=item.added_on
            to=item
    if type(to)!=qbittorrentapi.torrents.TorrentDictionary:
        logger.warning('未找到最新的种子')
        return True
    if not to._torrent_hash in hashlist:
        hashlist.append(to._torrent_hash)

    if 'lemonhd' in url:
        logger.info('发现lemonhd的种子,正在更改tracker...')
        for item in to.trackers:
            if 'url' in item and 'leaguehd' in item['url']:
                tracker=item['url']
                if 'http:' in tracker:
                    try:
                        to.edit_tracker(orig_url=tracker,new_url=tracker.replace('http:','https:'))
                    except Exception as r:
                        logger.error('更改tracker失败，原因: %s' %(r))

    return True



from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper

def hdpt_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://hdpt.xyz/takeupload.php"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    #选择类型
    if 'anime' in file1.pathinfo.type.lower():
        select_type='405'
        tags.append(18)
    elif 'tv' in file1.pathinfo.type.lower():
        select_type='402'
    elif 'movie' in file1.pathinfo.type.lower():
        select_type='401'
    elif 'show' in file1.pathinfo.type.lower():
        select_type='403'
    elif 'doc' in file1.pathinfo.type.lower():
        select_type='404'
    elif 'sport' in file1.pathinfo.type.lower():
        select_type='407'
    elif 'mv' in file1.pathinfo.type.lower():
        select_type='406'
    elif 'music' in file1.pathinfo.type.lower():
        select_type='409'
    elif 'cartoon' in file1.pathinfo.type.lower():
        select_type='412'
        tags.append(18)
    else:
        select_type='405'
        tags.append(18)
    logger.info('已成功填写类型为'+file1.pathinfo.type)


    #选择媒介
    if file1.type=='WEB-DL':
        medium_sel='10'
    elif 'webrip' in file1.type.lower():
        medium_sel='11'
    elif 'rip' in file1.type.lower():
        medium_sel='7'
    elif 'hdtv'in file1.type.lower():
        medium_sel='5'
    elif 'remux' in file1.type.lower():
        medium_sel='3'
    else:
        medium_sel='15'
    logger.info('已成功选择质量为'+file1.type)
   


    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='1'
    elif file1.Video_Format=='x264':
        codec_sel='1'
    elif file1.Video_Format=='H265':
        codec_sel='6'
    elif file1.Video_Format=='x265':
        codec_sel='6'
    else:
        codec_sel='1'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='5'
    elif '2160' in file1.standard_sel:
        standard_sel='5'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='1'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='2'
    elif '720' in file1.standard_sel:
        standard_sel='3'
    elif '480' in file1.standard_sel:
        standard_sel='4'
    else:
        standard_sel='1'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    
   #选择处理
    if 'rip' in file1.type.lower():
        processing_sel='2'
    else:
        processing_sel='1'
    logger.info('已选择处理为'+('rip' in file1.type.lower())*'Encode'+(1-('rip' in file1.type.lower()))*'Raw')

    #选择制作组
    if 'HDS' in file1.sub.upper():
        team_sel='1'
    elif 'CHD' in file1.sub.upper():
        team_sel='2'
    elif 'MYSILU' in file1.sub.upper():
        team_sel='3'
    elif 'WIKI' in file1.sub.upper():
        team_sel='4'
    elif 'HDH' in file1.sub.upper():
        team_sel='7'
    elif 'OURTV' in file1.sub.upper():
        team_sel='8'
    elif 'NGB' in file1.sub.upper():
        team_sel='9'
    elif 'U2' in file1.sub.upper():
        team_sel='10'
    elif 'LHD' in file1.sub.upper():
        team_sel='11'
    elif 'CHDBITS' in file1.sub.upper():
        team_sel='12'
    elif 'PTER' in file1.sub.upper():
        team_sel='13'
    elif 'CMCT' in file1.sub.upper():
        team_sel='14'
    elif 'FRDS' in file1.sub.upper():
        team_sel='15'
    elif 'HARES' in file1.sub.upper():
        team_sel='16'
    elif 'HDPT' in file1.sub.upper():
        team_sel='18'
    else:
        team_sel='17'
    logger.info('制作组已成功选择为'+file1.sub)
    
    if 'hdpt' in file1.sub.lower():
        tags.append(3)
        logger.info('已选择官方')
    if file1.pathinfo.transfer==0:
        tags.append(21)
        logger.info('已选择原创')
    if 'hdpt' in file1.pathinfo.exclusive :
        tags.append(1)
        logger.info('已选择禁转')
    if '国' in file1.language or '中' in file1.language:
        tags.append(5)
        logger.info('已选择国语')
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        tags.append(6)
        logger.info('已选择中字')

    
    tags=list(set(tags))
    tags.sort()
    
    if siteinfo.uplver==1:
        uplver='yes'
    else:
        uplver='no'

    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            

    other_data = {
            "name": file1.uploadname,
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "color": "0",
            "font": "0",
            "size": "0",
            "descr": file1.content,
            "type": select_type,
            "medium_sel": medium_sel,
            "codec_sel": codec_sel,
            "standard_sel": standard_sel,
            "processing_sel" : processing_sel,
            "team_sel": team_sel,
            "uplver": uplver,
            "tags[]": tags,
            }

    scraper=cloudscraper.create_scraper()
    r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper

def lemonhd_upload(web,file1,record_path,qbinfo,basic,hashlist):
    if 'anime' in file1.pathinfo.type.lower():
        return lemonhd_upload_anime(web,file1,record_path,qbinfo,basic,hashlist)
    elif 'tv' in file1.pathinfo.type.lower():
        return lemonhd_upload_tv(web,file1,record_path,qbinfo,basic,hashlist,'https://lemonhd.org/takeupload_tv.php')
    elif 'movie' in file1.pathinfo.type.lower():
        return lemonhd_upload_tv(web,file1,record_path,qbinfo,basic,hashlist,'https://lemonhd.org/takeupload_movie.php')



def lemonhd_upload_anime(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://lemonhd.org/takeupload_animate.php"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    

    #选择媒介
    if file1.type=='WEB-DL':
        animate_category='7'
    elif 'bdrip' in file1.type.lower() :
        animate_category='2'
    elif 'hdtvrip' in file1.type.lower() :
        animate_category='6'
    elif 'hdtv' in file1.type.lower():
        animate_category='5'
    elif 'remux' in file1.type.lower():
        animate_category='10'
    elif 'dvdrip' in file1.type.lower() :
        animate_category='4'
    else:
        animate_category='7'
    logger.info('已成功选择质量为'+file1.type)


    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='1'
    elif file1.Video_Format=='x264':
        codec_sel='12'
    elif file1.Video_Format=='H265':
        codec_sel='10'
    elif file1.Video_Format=='x265':
        codec_sel='11'
    else:
        codec_sel='1'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择音频编码
    if file1.Audio_Format.upper()=='AAC':
        audiocodec_sel='8'
    elif 'DTS-HD HR' in file1.Audio_Format.upper() or 'DTS-HDHR' in file1.Audio_Format.upper():
        audiocodec_sel='104'
    elif 'DTS-HDMA' in file1.Audio_Format.upper() or 'DTS-HD MA' in file1.Audio_Format.upper():
        audiocodec_sel='5'
    elif 'TrueHD Atmos' in file1.Audio_Format.upper():
        audiocodec_sel='1'
    elif 'LPCM' in file1.Audio_Format.upper():
        audiocodec_sel='15'
    elif 'TrueHD' in file1.Audio_Format.upper():
        audiocodec_sel='2'
    elif 'FLAC' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    elif 'APE' in file1.Audio_Format.upper():
        audiocodec_sel='11'
    elif 'MP3' in file1.Audio_Format.upper():
        audiocodec_sel='9'
    elif 'OGG' in file1.Audio_Format.upper():
        audiocodec_sel='10'
    elif 'AC3' in file1.Audio_Format.upper() or 'DD' in file1.Audio_Format.upper():
        audiocodec_sel='14'
    elif 'DTS:X' in file1.Audio_Format.upper() or 'DTS-X' in file1.Audio_Format.upper():
        audiocodec_sel='4'
    elif 'DTS' in file1.Audio_Format.upper():
        audiocodec_sel='6'
    elif 'WAV' in file1.Audio_Format.upper():
        audiocodec_sel='12'
    elif 'M4A' in file1.Audio_Format.upper():
        audiocodec_sel='13'
    else:
        audiocodec_sel='8'
    logger.info('已成功选择音频编码为'+file1.Audio_Format.upper())

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='6'
    elif '2160' in file1.standard_sel:
        standard_sel='1'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='2'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='2'
    elif '720' in file1.standard_sel:
        standard_sel='4'
    elif '480' in file1.standard_sel:
        standard_sel='5'
    else:
        standard_sel='2'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    
    #选择地区
    if not file1.country=='':
        if '大陆' in file1.country:
            processing_sel='1'
            logger.info('国家信息已选择'+file1.country)
        elif '香港' in file1.country:
            processing_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '台湾' in file1.country:
            processing_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '美国' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '英国' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '法国' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '韩国' in file1.country:
            processing_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '日本' in file1.country:
            processing_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '印度' in file1.country:
            processing_sel='5'
            logger.info('国家信息已选择'+file1.country)
        else:
            processing_sel='5'
            logger.info('未找到资源国家信息，已默认其他')
    else:
        processing_sel='4'
        logger.info('未找到资源国家信息，已默认日本')

    
    
    tag_jz='no'
    tag_gy='no'
    tag_zz='no'
    uplver='no'
    if 'lemonhd' in file1.pathinfo.exclusive and ('league' in file1.sub.lower() or 'lhd' in file1.sub.lower() or 'cint' in file1.sub.lower() or 'i18n' in file1.sub.lower() ):
        tag_jz='yes'
    if '国' in file1.language or '中' in file1.language:
        tag_gy='yes'
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        tag_zz='yes'
    if siteinfo.uplver==1:
        uplver='yes'


    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            

    other_data = {
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "douban_url": file1.doubanurl,
            "url" : file1.imdburl,
            "bangumi_url": file1.bgmurl,
            "anidb_url": file1.anidburl,
            "cn_name": file1.chinesename,
            "en_name": file1.englishname,
            "color": "0",
            "font": "0",
            "size": "0",
            "descr": file1.content,
            "year": str(file1.year),
            "animate_category": animate_category,
            "codec_sel": codec_sel,
            "audiocodec_sel": audiocodec_sel,
            "standard_sel": standard_sel,
            "processing_sel" : processing_sel,
            }
    buttomlist=["uplver","tag_jz","tag_zz","tag_gy"]
    for item in buttomlist:
        if eval(item+"=='yes'"):
            exec('other_data["'+item+'"]="yes"')
    #官组        
    if 'league' in file1.sub.lower():
        other_data['descr']=file1.douban_info+'\n[img]https://imgbox.leaguehd.com/images/2022/07/29/Movie-info-s3.png[/img]\n[quote=Mediainfo]\n'+file1.mediainfo+'\n[/quote]\n[img]https://imgbox.leaguehd.com/images/2022/07/29/Movie-screen-s3.png[/img]\n'+file1.screenshoturl

    if 'movie' in file1.pathinfo.type.lower():
        other_data['animate_type']='1'
        logger.info('已成功选择类型为movie')
        other_data['edition_sel']='1'
        logger.info('已成功选择类型为原版/普通版')
    else:
        if file1.pathinfo.collection==0:
            other_data['animate_type']='3'
            logger.info('已成功选择类型为TV')  
        else:
            other_data['animate_type']='6'
            logger.info('已成功选择类型为collection')

    if file1.pathinfo.complete==0:
        other_data['is_complete']='yes'
        logger.info('已成功选择未完结')
        other_data['series']='第'+file1.episodename+'话'
        
    elif file1.pathinfo.complete==1:
        other_data['series']='TV '+str(file1.pathinfo.min).zfill(2)+'-'+str(file1.pathinfo.max).zfill(2)+' Fin'
    else:
        other_data['series']='TV '+str(file1.pathinfo.min).zfill(2)+'-'+str(file1.pathinfo.max).zfill(2)
    logger.info('已成功填写集数')

    if 'i18n' in file1.sub.lower():
        other_data['team_sel']='9'
    elif 'lhd' in file1.sub.lower():
        other_data['team_sel']='14'
    elif 'leaguehd' in file1.sub.lower():
        other_data['team_sel']='8'
    elif 'leaguenf' in file1.sub.lower():
        other_data['team_sel']='12'
    elif 'leaguetv' in file1.sub.lower():
        other_data['team_sel']='10'
    elif 'leaguecd' in file1.sub.lower():
        other_data['team_sel']='11'
    elif 'leagueweb' in file1.sub.lower():
        other_data['team_sel']='13'
    elif 'cint' in file1.sub.lower():
        other_data['team_sel']='15'
    else:
        other_data['source_author']=file1.sub
    
    #选择来源

    if file1.pathinfo.transfer==1:
        other_data['original']='1'
        logger.info('已选择来源为转载')
        other_data['from_url']=file1.from_url
        logger.info('已成功填写转载地址')
    elif file1.pathinfo.transfer==0:
        other_data['original']='2'
        logger.info('已选择来源为原创')
    else:
        other_data['original']='1'
        logger.info('已默认来源为转载')
        other_data['from_url']=file1.from_url
        logger.info('已成功填写转载地址')

    scraper=cloudscraper.create_scraper()
    r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)








def lemonhd_upload_tv(siteinfo,file1,record_path,qbinfo,basic,hashlist,up_url):
    post_url = up_url
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename

    #选择版本
    edition_sel='1'
    logger.info('版本已选择原版')



    #选择媒介
    if file1.type=='WEB-DL':
        medium_sel='11'
    elif 'rip' in file1.type.lower() :
        medium_sel='7'
    elif 'hdtvrip' in file1.type.lower() :
        medium_sel='7'
    elif 'hdtv' in file1.type.lower():
        medium_sel='5'
    elif 'remux' in file1.type.lower():
        medium_sel='3'
    elif 'dvd' in file1.type.lower() :
        medium_sel='6'
    else:
        medium_sel='7'
    logger.info('已成功选择媒介为'+file1.type)



    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='1'
    elif file1.Video_Format=='x264':
        codec_sel='12'
    elif file1.Video_Format=='H265':
        codec_sel='10'
    elif file1.Video_Format=='x265':
        codec_sel='11'
    else:
        codec_sel='1'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择音频编码
    if file1.Audio_Format.upper()=='AAC':
        audiocodec_sel='8'
    elif 'DTS-HD HR' in file1.Audio_Format.upper() or 'DTS-HDHR' in file1.Audio_Format.upper():
        audiocodec_sel='104'
    elif 'DTS-HDMA' in file1.Audio_Format.upper() or 'DTS-HD MA' in file1.Audio_Format.upper():
        audiocodec_sel='5'
    elif 'TrueHD Atmos' in file1.Audio_Format.upper():
        audiocodec_sel='1'
    elif 'LPCM' in file1.Audio_Format.upper():
        audiocodec_sel='15'
    elif 'TrueHD' in file1.Audio_Format.upper():
        audiocodec_sel='2'
    elif 'FLAC' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    elif 'APE' in file1.Audio_Format.upper():
        audiocodec_sel='11'
    elif 'MP3' in file1.Audio_Format.upper():
        audiocodec_sel='9'
    elif 'OGG' in file1.Audio_Format.upper():
        audiocodec_sel='10'
    elif 'AC3' in file1.Audio_Format.upper() or 'DD' in file1.Audio_Format.upper():
        audiocodec_sel='14'
    elif 'DTS:X' in file1.Audio_Format.upper() or 'DTS-X' in file1.Audio_Format.upper():
        audiocodec_sel='4'
    elif 'DTS' in file1.Audio_Format.upper():
        audiocodec_sel='6'
    elif 'WAV' in file1.Audio_Format.upper():
        audiocodec_sel='12'
    elif 'M4A' in file1.Audio_Format.upper():
        audiocodec_sel='13'
    else:
        audiocodec_sel='8'
    logger.info('已成功选择音频编码为'+file1.Audio_Format.upper())

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='6'
    elif '2160' in file1.standard_sel:
        standard_sel='1'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='2'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='2'
    elif '720' in file1.standard_sel:
        standard_sel='4'
    elif '480' in file1.standard_sel:
        standard_sel='5'
    else:
        standard_sel='2'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    
    #选择地区
    if not file1.country=='':
        if '大陆' in file1.country:
            processing_sel='1'
            logger.info('国家信息已选择'+file1.country)
        elif '香港' in file1.country:
            processing_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '台湾' in file1.country:
            processing_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '美国' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '英国' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '法国' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '韩国' in file1.country:
            processing_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '日本' in file1.country:
            processing_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '印度' in file1.country:
            processing_sel='5'
            logger.info('国家信息已选择'+file1.country)
        else:
            processing_sel='5'
            logger.info('未找到资源国家信息，已默认其他')
    else:
        processing_sel='4'
        logger.info('未找到资源国家信息，已默认日本')
    
    
    tag_jz='no'
    tag_gy='no'
    tag_zz='no'
    uplver='no'
    if 'lemonhd' in file1.pathinfo.exclusive and ('league' in file1.sub.lower() or 'lhd' in file1.sub.lower() or 'cint' in file1.sub.lower() or 'i18n' in file1.sub.lower() ):
        tag_jz='yes'
    if '国' in file1.language or '中' in file1.language:
        tag_gy='yes'
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        tag_zz='yes'
    if siteinfo.uplver==1:
        uplver='yes'
    

    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            

    other_data = {
            "name": file1.uploadname,
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "douban_url": file1.doubanurl,
            "url" : file1.imdburl,
            "color": "0",
            "font": "0",
            "size": "0",
            "descr": file1.content,
            "edition_sel" : edition_sel,
            "medium_sel": medium_sel,
            "codec_sel": codec_sel,
            "audiocodec_sel": audiocodec_sel,
            "standard_sel": standard_sel,
            "processing_sel" : processing_sel,
            }

    buttomlist=["uplver","tag_jz","tag_zz","tag_gy"]
    for item in buttomlist:
        if eval(item+"=='yes'"):
            exec('other_data["'+item+'"]="yes"')

    #官组        
    if 'league' in file1.sub.lower():
        other_data['descr']=file1.douban_info+'\n[img]https://imgbox.leaguehd.com/images/2022/07/29/Movie-info-s3.png[/img]\n[quote=Mediainfo]\n'+file1.mediainfo+'\n[/quote]\n[img]https://imgbox.leaguehd.com/images/2022/07/29/Movie-screen-s3.png[/img]\n'+file1.screenshoturl
    
    if 'tv' in file1.pathinfo.type.lower():
        if 'show' in file1.pathinfo.type.lower():
            other_data['type']='403'
            logger.info('已成功选择类型为TV Shows(综艺)')
        else:
            other_data['type']='402'
            logger.info('已成功选择类型为TV Series(电视剧)')
        if file1.pathinfo.complete==1:
            other_data['is_complete']='yes'

        other_data['t_season']=file1.season
        
        if file1.pathinfo.collection==0:
            other_data['series']='E'+file1.episodename
        elif file1.pathinfo.complete==1:
            other_data['series']='E'+str(file1.pathinfo.min).zfill(2)+'-E'+str(file1.pathinfo.max).zfill(2)+' Fin'
        else:
            other_data['series']='E'+str(file1.pathinfo.min).zfill(2)+'-E'+str(file1.pathinfo.max).zfill(2)
        logger.info('已成功填写集数')
    
    if 'movie' in file1.pathinfo.type.lower():
        other_data['type']='401'

    #选择制作组
    if 'i18n' in file1.sub.lower():
        other_data['team_sel']='9'
        logger.info('制作组已成功选择为'+file1.sub)
    elif 'lhd' in file1.sub.lower():
        other_data['team_sel']='14'
        logger.info('制作组已成功选择为'+file1.sub)
    elif 'leaguehd' in file1.sub.lower():
        other_data['team_sel']='8'
        logger.info('制作组已成功选择为'+file1.sub)
    elif 'leaguenf' in file1.sub.lower():
        other_data['team_sel']='12'
        logger.info('制作组已成功选择为'+file1.sub)
    elif 'leaguetv' in file1.sub.lower():
        other_data['team_sel']='10'
        logger.info('制作组已成功选择为'+file1.sub)
    elif 'leaguecd' in file1.sub.lower():
        other_data['team_sel']='11'
        logger.info('制作组已成功选择为'+file1.sub)
    elif 'leagueweb' in file1.sub.lower():
        other_data['team_sel']='13'
        logger.info('制作组已成功选择为'+file1.sub)
    elif 'cint' in file1.sub.lower():
        other_data['team_sel']='15'
        logger.info('制作组已成功选择为'+file1.sub)
    else:
        logger.info('非官组资源')
    
    if file1.pathinfo.transfer==1:
        other_data['from_url']=file1.from_url
        logger.info('已成功填写转载地址')


    scraper=cloudscraper.create_scraper()
    r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


import argparse
import os


def readargs():
    mainpath = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
    yaml_path = os.path.join(mainpath,"au.yaml")
    basic_path = os.path.join(mainpath,"basicinfo.yaml")
    parser = argparse.ArgumentParser(description='Weclome Upload_Machine By Sauterne')
    parser.add_argument('-u','--upload', action='store_true', default=False, help='Upload local resources automatically')
    parser.add_argument('-s','--sign', action='store_true', default=False, help='SignUp automatically')
    parser.add_argument('-iu','--img-upload', action='store_true', default=False, help='Upload picture as url')
    parser.add_argument('-di','--douban-info', action='store_true', default=False, help='Get douban info')
    parser.add_argument('-mi','--media-img', action='store_true', default=False, help='Get screenshots of the video and upload the image')

    parser.add_argument('-ih','--img-host', type=str, help='Choose your img host from the following list. [ptpimg,picgo,chd,smms,pter,emp,femp,imgbox,freeimage]',choices=['ptpimg','picgo','chd','smms','pter','emp','femp','imgbox','freeimage'],required=False,default='')
    parser.add_argument('-if','--img-file', nargs='+',help='Choose your img file',action='append',required=False)
    parser.add_argument('-iform','--img-form', help='Choose your img form the following list. [bbcode,img]',choices=['bbcode','img'],required=False,default='img')

    parser.add_argument('-du','--douban-url', type=str, help='Input your douban-url',required=False,default='')

    parser.add_argument('-mf','--media-file', type=str, help='Choose your mediafile',required=False,default='')
    parser.add_argument('-in','--img-num', type=int, help='Choose the number of screenshots,default=3',required=False,default=3)


    
    parser.add_argument('-yp','--yaml-path', type=str, help='Path of your au.yaml',required=True,default=yaml_path)
    parser.add_argument('-bp','--basic-path', type=str, help='Path of your basicinfo.yaml',required=False,default=basic_path)
    args = parser.parse_args()
    return args



from loguru import logger
import json
import os.path

class site(object):
    def __init__(self,sitename,sitedict):
        self.sitename   = sitename
        self.exist_cookie=False
        self.exist_password=False
        self.uplver =1
        self.enable =0
        self.check = False
        self.mediainfo_template_file=''


        try:
            self.uplver =int(sitedict['uplver'])
        except:
            logger.warning(sitename+'站点匿名发布uplver信息填错错误，已设置为1:默认匿名发布')
            self.uplver =1
            sitedict['uplver']=1

        if not (self.uplver==0 or self.uplver==1):
            logger.warning(sitename+'站点匿名发布uplver信息填错错误，已设置为1:默认匿名发布')
            self.uplver =1
            sitedict['uplver']=1

        if 'mediainfo_template_file' in sitedict and sitedict['mediainfo_template_file']!= None and sitedict['mediainfo_template_file'].strip()!='':
            if os.path.exists(sitedict['mediainfo_template_file']):
                self.mediainfo_template_file=sitedict['mediainfo_template_file']
            else:
                raise Exception(sitename+'站点的mediainfo模板文件不存在')
        else:
            self.mediainfo_template_file=''


        try:
            self.enable =int(sitedict['enable'])
        except:
            logger.warning(sitename+'站点enable信息填错错误，已设置为0:关闭')
            self.enable =0
            sitedict['enable']=0

        if not (self.enable==0 or self.enable==1):
            logger.warning(sitename+'站点匿名发布enable信息填错错误，已设置为0:关闭')
            self.enable =0
            sitedict['enable']=0
        '''
        if 'tracker' in sitedict and not sitedict['tracker']==None:
            self.tracker = sitedict['tracker']
        else:
            sitedict['tracker']='https://tracker.pterclub.com/announce'
        '''
        if 'cookie' in sitedict :
            self.cookie=sitedict['cookie']
            self.exist_cookie=True
        else:
            self.cookie=''
            self.exist_cookie=False

        if 'check' in sitedict :
            if str(sitedict['check']=='1'):
                self.check=True
            else:
                self.check=False
        if 'username' in sitedict and not sitedict['username']==None and 'password' in sitedict and not sitedict['password']==None:
            self.username   = sitedict['username']
            self.password   = sitedict['password']
            self.exist_password=True

        if self.enable==1 and (not self.exist_cookie and not self.exist_password):
            logger.error('未找到'+sitename+' 站点的cookie信息以及用户名密码信息，请至少填写一个')
            raise ValueError ('未找到'+sitename+' 站点的cookie信息以及用户名密码信息，请至少填写一个')

    def print(self):

        print('Site info:')
        print('sitename:'  ,self.sitename  )
        print('enable:'    ,self.enable    )
        print('url:'       ,self.url       )
        print('loginurl:'  ,self.loginurl  )
        print('uploadurl:' ,self.uploadurl )
        print('tracker:'   ,self.tracker   )
        if self.exist_password:
            print('username:'  ,self.username  )
            print('password:'  ,self.password  )
        else:
            print('username:未设置或未识别')
            print('password:未设置或未识别')
        if self.exist_cookie:
            print('cookie:',self.cookie)
        else:
            print('cookiefile:未设置或未识别')
        print('')

def makesites(siteinfo):
    sites=dict()
    for item in siteinfo:
        sites[item]=site(item,siteinfo[item])
    return sites











from upload_machine.utils.para_ctrl.readyaml import readyaml
from upload_machine.utils.para_ctrl.readargs import readargs
from upload_machine.utils.para_ctrl.readyaml import write_yaml
import os
from loguru import logger

def read_para():
    args = readargs()

    iu=0#img upload
    su=0#sign
    ru=0#resources upload
    if not args.img_upload+args.sign+args.upload+args.douban_info+args.media_img==1:
        logger.error('参数输入错误，上传模式 -u,签到模式 -s,上传图床模式 -iu,获取豆瓣信息 -di, 获取视频截图链接 -mi, 必须且只能选择一个。')
        raise ValueError ('参数输入错误，上传模式 -u,签到模式 -s,上传图床模式 -iu,获取豆瓣信息 -di, 获取视频截图链接 -mi, 必须且只能选择一个。')


    au_data   = readyaml(args.yaml_path)
    basic_data = readyaml(args.basic_path)
    merge_para(basic_data,au_data)

    if 'basic' in au_data and 'workpath' in au_data['basic']:
        if not os.path.exists(au_data['basic']['workpath']):
            logger.info('检测到workpath目录并未创建，正在新建文件夹：'+au_data['basic']['workpath'])
            os.makedirs(au_data['basic']['workpath'])
        itemlist=['record_path','screenshot_path']
        for item in itemlist:
            if not item in au_data['basic']:
                au_data['basic'][item]=os.path.join(au_data['basic']['workpath'],item)
                if not os.path.exists(au_data['basic'][item]):
                    logger.info('检测到'+item+'目录并未创建，正在新建文件夹：'+au_data['basic'][item])
                    os.makedirs(au_data['basic'][item])

    au_data['yaml_path']=args.yaml_path
    write_yaml(au_data)
    
    au_data['mod']=args.media_img*'media_img'+args.img_upload*'img_upload'+args.sign*'sign'+args.upload*'upload'+args.douban_info*'douban_info'

    if args.upload:
        if not 'path info' in au_data or len(au_data['path info'])==0:
            logger.error('参数输入错误，发布资源请至少输入一个本地文件地址')
            raise ValueError ('参数输入错误，发布资源请至少输入一个本地文件地址')
        for item in au_data['path info']:
            if not 'path' in au_data['path info'][item] or au_data['path info'][item]['path']==None or au_data['path info'][item]['path']=='':
                logger.error('参数输入错误，'+item+'请至少输入一个本地文件地址')
                raise ValueError ('参数输入错误，'+item+'请至少输入一个本地文件地址')
            if 'type' in au_data['path info'][item] and not ( 'anime' in au_data['path info'][item]['type'].lower() or 'tv' in au_data['path info'][item]['type'].lower() or 'movie' in au_data['path info'][item]['type'].lower()):
                logger.error('参数输入错误，'+item+'的type类型暂不支持')
                raise ValueError ('参数输入错误，'+item+'的type类型暂不支持')
        if not 'qbinfo' in au_data:
            logger.error('参数输入错误，未找到qbinfo')
            raise ValueError ('参数输入错误，未找到qbinfo')
        if not 'start' in au_data['qbinfo'] or not (int(au_data['qbinfo']['start'])==1 or int(au_data['qbinfo']['start'])==0):
            au_data['qbinfo']['start']=0
            logger.warning('未找到qbinfo中的start(添加到qb的种子是否自动开始)参数,已设置为0(不自动开始)')



    
    if args.img_upload:
        if 'img_host' in args and not args.img_host=='':
            au_data['img_host']=args.img_host
        else:
            au_data['img_host']=''

        if 'img_form' in args and not args.img_form=='':
            au_data['img_form']=args.img_form
        else:
            au_data['img_form']='img'

        filelist=[]
        if 'img_file' in args and args.img_file==None:
            logger.error('参数输入错误，上传图片请至少输入一个本地文件地址')
            raise ValueError ('参数输入错误，上传图片请至少输入一个本地文件地址')
        for item in args.img_file:
            for imgitem in item:
                if not imgitem in filelist:
                    filelist.append(imgitem)
        if len(filelist)==0:
            logger.error('参数输入错误，上传图片请至少输入一个本地文件地址')
            raise ValueError ('参数输入错误，上传图片请至少输入一个本地文件地址')
        au_data['imgfilelist']=filelist

    if args.douban_info:
        
        if not 'douban_url' in args or ( args.douban_info==None or args.douban_info==''):
            logger.error('参数输入错误，请输入--douban-url 豆瓣链接')
            raise ValueError ('参数输入错误，请输入--douban-url 豆瓣链接')
        
        au_data['douban_url']=args.douban_url

    if args.media_img:

        if not 'media_file' in args or ( args.media_file==None or args.media_file==''):
            logger.error('参数输入错误，请输入media-file 视频文件路径')
            raise ValueError ('参数输入错误，请输入media-file 视频文件路径')

        if not 'basic' in au_data or not 'picture_num' in au_data['basic'] or ( au_data['basic']['picture_num']==None or au_data['basic']['picture_num']==''):
            logger.warning('未找到yaml文件中截图数量参数picture_num,已设置为3')
            if not 'basic' in au_data:
                au_data['basic']=dict()
            au_data['basic']['picture_num']=3

        if not 'basic' in au_data or not 'screenshot_path' in au_data['basic'] or ( au_data['basic']['screenshot_path']==None or au_data['basic']['screenshot_path']==''):
            logger.error('参数输入错误，请前往yaml文件配置截图路径参数screenshot_path')
            raise ValueError ('参数输入错误，请前往yaml文件配置截图路径参数screenshot_path')

        if 'img_host' in args and not args.img_host=='':
            au_data['img_host']=args.img_host
        else:
            au_data['img_host']=''

        if 'img_form' in args and not args.img_form=='':
            au_data['img_form']=args.img_form
        else:
            au_data['img_form']='img'

        if 'img_num' in args and not (args.img_num=='' or args.img_num==None) :
            au_data['basic']['picture_num']=int(args.img_num)



        au_data['media_file']=args.media_file







    return au_data

def merge_para(dict1,dict2):
    '''
    将dict1中的内容合并入dict2,如果有相同内容保持dict2
    '''
    if not (type(dict1)==dict and type(dict2)==dict):
        return 
    for item in dict1:
        if item in dict2:
            merge_para(dict1[item],dict2[item])
        else:
            dict2[item]=dict1[item]




#import upload_machine.utils.para_ctrl.readyaml
#import upload_machine.utils.para_ctrl.readargs

#readyaml = upload_machine.utils.para_ctrl.readyaml.readyaml
#readargs = upload_machine.utils.para_ctrl.readargs.readargs


from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper

def pter_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://pterclub.com/takeupload.php"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    #选择类型
    if 'anime' in file1.pathinfo.type.lower():
        select_type='403'
    elif 'tv' in file1.pathinfo.type.lower():
        select_type='404'
    elif 'movie' in file1.pathinfo.type.lower():
        select_type='401'
    else:
        select_type='403'
    logger.info('已成功填写类型为'+file1.pathinfo.type)


    #选择来源 
    if file1.type=='WEB-DL':
        source_sel='5'
    elif 'rip' in file1.type.lower() or file1.type=='bluray'  :
        source_sel='6'
    elif file1.type=='HDTV':
        source_sel='4'
    elif file1.type=='remux':
        source_sel='3'
    else:
        source_sel='6'
    logger.info('已成功选择质量为'+file1.type)
    
    #选择地区
    if not file1.country=='':
        if '大陆' in file1.country:
            team_sel='1'
            logger.info('国家信息已选择'+file1.country)
        elif '香港' in file1.country:
            team_sel='2'
            logger.info('国家信息已选择'+file1.country)
        elif '台湾' in file1.country:
            team_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '美国' in file1.country:
            team_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '英国' in file1.country:
            team_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '法国' in file1.country:
            team_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '韩国' in file1.country:
            team_sel='5'
            logger.info('国家信息已选择'+file1.country)
        elif '日本' in file1.country:
            team_sel='6'
            logger.info('国家信息已选择'+file1.country)
        elif '印度' in file1.country:
            team_sel='7'
            logger.info('国家信息已选择'+file1.country)
        else:
            team_sel='6'
            logger.info('未找到资源国家信息，已默认日本')
    else:
        team_sel='6'
        logger.info('未找到资源国家信息，已默认日本')


    jinzhuan = 'no'
    guoyu    = 'no'
    zhongzi  = 'no'
    pr       = 'no'
    guanfang = 'no'
    uplver   = 'no'
    if 'audience' in file1.pathinfo.exclusive :
        jinzhuan = 'yes'
    if '国' in file1.language or '中' in file1.language:
        guoyu    = 'yes'
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        zhongzi  = 'yes'
    if file1.transfer==0:
        pr = 'yes'
    if 'PTER' in file1.sub.upper():
        guanfang = 'yes'
    
    tags=list(set(tags))
    tags.sort()
    
    if siteinfo.uplver==1:
        uplver='yes'

        

    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            
    
    other_data = {
            "name": file1.uploadname,
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "url": file1.imdburl,
            "douban": file1.doubanurl,
            "color": "0",
            "font": "0",
            "size": "0",
            "descr": file1.content.replace('[quote=','[hide=').replace('[/quote','[/hide'),
            "type": select_type,
            "source_sel": source_sel,
            "team_sel": team_sel,
            }
    buttomlist=["uplver","jinzhuan","guoyu","zhongzi","pr","guanfang"]
    for item in buttomlist:
        if eval(item+"=='yes'"):
            exec('other_data["'+item+'"]="yes"')
            

    scraper=cloudscraper.create_scraper()
    r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


import re
import json
from pathlib import Path
from typing import Optional
import requests
from loguru import logger
from bs4 import BeautifulSoup
from urllib.parse import urlparse

def url_to_domain(url):
     o = urlparse(url)
     domain = o.hostname
     return domain.split('.')[-2]

def get_token(url:str,cookie:str):
    headers={
    'cookie': cookie,
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.51 Safari/537.36'}
    try:
        response=requests.get(url=url,headers=headers)
    except Exception as r:
        logger.warning('获取token失败，原因: %s' %(r))
        return ''
    content=response.text
    soup=BeautifulSoup(content,'lxml')
    for link in soup.find_all("a"):
        links=link.get("href") 
        if 'auth_token' in links:
            return links[links.find('auth_token')+11:]
    return ''

def chevereto_api_upload(imgpath: str, url: str, api_key: str):
    img  = Path(imgpath)
    data = {'key': api_key}
    files = {'source': open(img, 'rb')}
    try:
        req = requests.post(f'{url}/api/1/upload', data=data, files=files)
    except Exception as r:
        logger.warning('requests 获取失败，原因: %s' %(r))
    try:
        res = req.json()
        logger.trace(res)
    except json.decoder.JSONDecodeError:
        res = {}
    if not req.ok:
        logger.trace(req.content)
        logger.warning(
            f"上传图片失败: HTTP {req.status_code}, reason: {req.reason} "
            f"{res['error'].get('message') if 'error' in res else ''}")
        return None
    if 'error' in res:
        logger.warning(f"上传图片失败: [{res['error'].get('code')}]{res['error'].get('message')}")
        return None
    if 'image' not in res or 'url' not in res['image']:
        logger.warning(f"图片直链获取失败")
        return None
    return res['image']['url']


def chevereto_cookie_upload(imgpath: str, url: str, cookie: str):
    auth_token=get_token(url,cookie)
    if auth_token=='':
        logger.warning('未找到auth_token')
        return None

    img  = Path(imgpath)
    headers = {'cookie': cookie}
    data = {'type': 'file', 'action': 'upload', 'nsfw': 0, 'auth_token': auth_token}
    files = {'source': open(img, 'rb')}

    try:
        req = requests.post(f'{url}/json', data=data, files=files, headers=headers)
    except Exception as r:
        logger.warning('requests 获取失败，原因: %s' %(r))
    try:
        res = req.json()
        logger.trace(res)
    except json.decoder.JSONDecodeError:
        res = {}
    if not req.ok:
        logger.warning(
            f"上传图片失败: HTTP {req.status_code}, reason: {req.reason} "
            f"{res['error'].get('message') if 'error' in res else ''}")
        return None
    if 'error' in res:
        logger.warning(f"上传图片失败: [{res['error'].get('code')}] {res['error'].get('context')} {res['error'].get('message')}")
        return None
    if 'status_code' in res and res.get('status_code') != 200:
        logger.warning(f"上传图片失败: [{res['status_code']}] {res.get('status_txt')}")
        return None 
    if 'image' not in res or 'url' not in res['image']:
        logger.warning(f"图片直链获取失败")
        return None
    return res['image']['url']

def chevereto_api_upload_files(imgpaths: list,url: str, api_key: str, form='img'):
    liststr=''
    imgnum=0
    domain=url_to_domain(url)
    for imgpath in imgpaths:
        imgnum=imgnum+1
        trynum=0
        success=0
        imgstr=''
        while success==0 and trynum<5:
            trynum=trynum+1
            try:
                imgstr=chevereto_api_upload(imgpath,url,api_key)
                success=1
            except Exception as r:
                success=0
                logger.warning(domain+'第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...原因: %s' %(r))
            if imgstr==None:
                success=0
                logger.warning(domain+'第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...')
        if success==1:
            if form.lower()=='img':
                liststr=liststr+imgstr+'\n'
            elif form.lower()=='bbcode':
                liststr=liststr+'[img]'+imgstr+'[/img]\n'
            else:
                liststr=liststr+imgstr+'\n'
            logger.info(domain+'第'+str(imgnum)+'张图片上传成功！')
        else:
            logger.warning(domain+'第'+str(imgnum)+'张图片'+imgpath+'上传失败')
    return liststr.strip()

def chevereto_cookie_upload_files(imgpaths: list,url: str, cookie: str, form='img'):
    liststr=''
    imgnum=0
    domain=url_to_domain(url)
    for imgpath in imgpaths:
        imgnum=imgnum+1
        trynum=0
        success=0
        imgstr=''
        while success==0 and trynum<5:
            trynum=trynum+1
            try:
                imgstr=chevereto_cookie_upload(imgpath,url,cookie)
                success=1
            except Exception as r:
                success=0
                logger.warning(domain+'第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...原因: %s' %(r))
            if imgstr==None:
                success=0
                logger.warning(domain+'第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...')
        if success==1:
            if form.lower()=='img':
                liststr=liststr+imgstr+'\n'
            elif form.lower()=='bbcode':
                liststr=liststr+'[img]'+imgstr+'[/img]\n'
            else:
                liststr=liststr+imgstr+'\n'
            logger.info(domain+'第'+str(imgnum)+'张图片上传成功！')
        else:
            logger.warning(domain+'第'+str(imgnum)+'张图片'+imgpath+'上传失败')
    return liststr.strip()

#p1="/Users/moyu/Downloads/在线视频十大品牌-视频app排行榜-视频网站排行榜-买购品牌网 (2).png"
#p2="/Users/moyu/Downloads/zhizhu.jpg"
#imgpaths=[p1,p2]
#key='chv_SVbN_71d381f1cefd83182c17337618060ed19f00232f809b12b6f1eeb8f5c5180714b1d0bb2b4b91f265dbbd0c4ea336eb840a637b92bdb7ba41c71c36c862a442a4'
#url='https://www.picgo.net/api/1/upload'
#print(chevereto_api_upload(p,url,key))
#print(chevereto_api_upload_files(imgpaths,url,key,'bbcode'))




#auth_token='5b22483f1d360d3aab9c51ff95e18e0e2fb3aaf2'
#url='https://s3.pterclub.com'
#cookie='KEEP_LOGIN=a4Np%3A575db23e5a8bb04e125711db411b9c18cee2c10dfa6e5ffce3be1d3a068c55c3c93f822a509746e5e84bdb71bc15b87bdf11e1a1361fda194cb5373fd9ff81fbaaef26119313e7a9b7e1aa96fde2032a64b451a87702ca42997bbdf1e7f8f11394991b795c%3A1658856793; PHPSESSID=t6usd4455j8dle6jr71oc6jpkm'
#p='/Users/moyu/Downloads/1.png'
#auth_token='2ff56e94fe9a5e817dfb5a20211df8677d1243f0'
#cookie='PHPSESSID=7a5tf1pcrpttglphd0rlid7rpq; AGREE_CONSENT=1; KEEP_LOGIN=CPT%3A11717c9cc52cbcd96397bd68d2178737bfd4839973ff561f4401af4c59ba84c4b30af45e5b8cb497b4d79e7bb5653f7b670f5bd6be833ae6dc122e63c63c54391e4782918be061dbbcf1776136dbe14c28040551e2730c59c358091cf6fc8625804a1d3647a19bc2%3A1658892099'
#url='https://jerking.empornium.ph'
#print(chevereto_cookie_upload(p,url,cookie,auth_token))





